@@ -306,7 +306,7 @@ mod test {
             let authorized = keyed_account.unsigned_key();
             keyed_account
                 .initialize_nonce_account(
-                    &authorized,
+                    authorized,
                     &recent_blockhashes,
                     &rent,
                     &MockInvokeContext::new(vec![]),
@@ -367,7 +367,7 @@ mod test {
                 keyed_account
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -597,7 +597,7 @@ mod test {
                 nonce_keyed
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -639,7 +639,7 @@ mod test {
                 let lamports = nonce_keyed.account.borrow().lamports();
                 let result = nonce_keyed.withdraw_nonce_account(
                     lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -669,7 +669,7 @@ mod test {
                 let lamports = nonce_keyed.account.borrow().lamports() + 1;
                 let result = nonce_keyed.withdraw_nonce_account(
                     lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -699,7 +699,7 @@ mod test {
                 nonce_keyed
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -722,7 +722,7 @@ mod test {
                 nonce_keyed
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -779,7 +779,7 @@ mod test {
                 nonce_keyed
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -808,7 +808,7 @@ mod test {
                 nonce_keyed
                     .withdraw_nonce_account(
                         withdraw_lamports,
-                        &to_keyed,
+                        to_keyed,
                         &recent_blockhashes,
                         &rent,
                         &signers,
@@ -852,7 +852,7 @@ mod test {
                 let withdraw_lamports = nonce_keyed.account.borrow().lamports();
                 let result = nonce_keyed.withdraw_nonce_account(
                     withdraw_lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -888,7 +888,7 @@ mod test {
                 let withdraw_lamports = nonce_keyed.account.borrow().lamports() + 1;
                 let result = nonce_keyed.withdraw_nonce_account(
                     withdraw_lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -924,7 +924,7 @@ mod test {
                 let withdraw_lamports = nonce_keyed.account.borrow().lamports() - min_lamports + 1;
                 let result = nonce_keyed.withdraw_nonce_account(
                     withdraw_lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -960,7 +960,7 @@ mod test {
                 let withdraw_lamports = u64::MAX - 54;
                 let result = nonce_keyed.withdraw_nonce_account(
                     withdraw_lamports,
-                    &to_keyed,
+                    to_keyed,
                     &recent_blockhashes,
                     &rent,
                     &signers,
@@ -1149,7 +1149,7 @@ mod test {
             let authorized = &Pubkey::default().clone();
             nonce_account
                 .initialize_nonce_account(
-                    &authorized,
+                    authorized,
                     &recent_blockhashes,
                     &rent,
                     &MockInvokeContext::new(vec![]),
@@ -1176,7 +1176,7 @@ mod test {
             let authorized = nonce_account.unsigned_key();
             nonce_account
                 .initialize_nonce_account(
-                    &authorized,
+                    authorized,
                     &recent_blockhashes,
                     &Rent::free(),
                     &MockInvokeContext::new(vec![]),
@@ -1211,7 +1211,7 @@ mod test {
             let authorized = nonce_account.unsigned_key();
             nonce_account
                 .initialize_nonce_account(
-                    &authorized,
+                    authorized,
                     &recent_blockhashes,
                     &Rent::free(),
                     &MockInvokeContext::new(vec![]),
